@@ -1,5 +1,5 @@
 import logging
-from typing import List, Dict, Tuple
+from typing import List, Dict, Tuple, Optional
 
 from .base_ssdb import BaseSsdb
 from .utils import SsdbResponseUtils
@@ -7,6 +7,9 @@ from .utils import SsdbResponseUtils
 
 class BaseSsdbSortedSet(BaseSsdb):
 
+    def zsize(self, name: str) -> int:
+        pass
+
     def zset(self, name: str, key: str, score: float):
         pass
 
@@ -28,7 +31,13 @@ class BaseSsdbSortedSet(BaseSsdb):
     def zrrange(self, name: str, offset: int, size: int) -> List[Tuple[str, float]]:
         pass
 
-    def multi_get_item_by_ranking(self, name: str, ranks: List[int]) -> Dict[int, str]:
+    def get_ranking(self, name: str, rank: int) -> Optional[Tuple[int, str]]:
+        pass
+
+    def multi_get_ranking(self, name: str, ranks: List[int]) -> Dict[int, str]:
+        pass
+
+    def multi_get_ranking2(self, name: str, ranks: List[int]) -> Dict[int, str]:
         pass
 
     def zdel(self, name: str, key: str):
@@ -43,6 +52,10 @@ class BaseSsdbSortedSet(BaseSsdb):
 
 class SsdbSortedSet(BaseSsdbSortedSet):
 
+    def zsize(self, name: str) -> int:
+        result = self.execute_command('zsize', name)
+        return result
+
     def zset(self, name: str, key: str, score: float):
         result = self.execute_command(
             'zset',
@@ -85,7 +98,31 @@ class SsdbSortedSet(BaseSsdbSortedSet):
             for k, v in SsdbResponseUtils.response_to_pair_list(result)
         ]
 
-    def multi_get_item_by_ranking(self, name: str, ranks: List[int]) -> Dict[int, str]:
+    def get_ranking(self, name: str, rank: int) -> Optional[Tuple[int, str]]:
+        if rank > 0:
+            start_rank, end_rank = rank, rank
+            response = self.execute_command('zrange', name, start_rank, end_rank + 1)
+            rank_to_id_map = SsdbResponseUtils.to_rank_to_id_map(response, [rank], start_rank)
+
+            id = rank_to_id_map.get(rank, None)
+        else:
+            id = None
+
+        return (rank, id) if id is not None else None
+
+    def multi_get_ranking2(self, name: str, ranks: List[int]) -> Dict[int, str]:
+        rank_2_ids: Dict[int, str] = {}
+
+        if len(ranks) > 0:
+            for rank in ranks:
+                result = self.get_ranking(name, rank)
+                if result is not None:
+                    rank = int(result[0])
+                    id = str(result[1])
+                    rank_2_ids[rank] = id
+        return rank_2_ids
+
+    def multi_get_ranking(self, name: str, ranks: List[int]) -> Dict[int, str]:
         actual_result_map: Dict[int, str] = {}
 
         if len(ranks) > 0:
@@ -100,7 +137,7 @@ class SsdbSortedSet(BaseSsdbSortedSet):
             logging.info('multi_get_item_by_ranking')
             logging.info(f"Range: [{start_rank}, {end_rank + 1})")
             logging.info(f"Response Size: {len(response[::2])}")
-            logging.info(f"Final Size: {len(actual_result_map.keys())}")
+            logging.info(f"Final Result: {len(actual_result_map.keys())} - {actual_result_map}")
 
         return actual_result_map
 
